# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.datasets_v1_api import DatasetsV1Api


class TestDatasetsV1Api(unittest.TestCase):
    """DatasetsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = DatasetsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_dataset(self) -> None:
        """Test case for delete_dataset

        Delete Dataset
        """
        pass

    def test_get_available_dataset(self) -> None:
        """Test case for get_available_dataset

        Get Available Dataset By Id
        """
        pass

    def test_get_connector_available_datasets(self) -> None:
        """Test case for get_connector_available_datasets

        Get Available Datasets By Connector Id
        """
        pass

    def test_get_connector_datasets(self) -> None:
        """Test case for get_connector_datasets

        Get Datasets By Connector Id
        """
        pass

    def test_get_dataset(self) -> None:
        """Test case for get_dataset

        Get Dataset By Id
        """
        pass

    def test_get_datasets(self) -> None:
        """Test case for get_datasets

        Get Datasets
        """
        pass

    def test_get_datasets_in_workspace(self) -> None:
        """Test case for get_datasets_in_workspace

        Get Workspace Datasets.
        """
        pass

    def test_patch_dataset(self) -> None:
        """Test case for patch_dataset

        Update Dataset
        """
        pass

    def test_post_available_dataset(self) -> None:
        """Test case for post_available_dataset

        Create Single Available Dataset
        """
        pass

    def test_post_connector_dataset(self) -> None:
        """Test case for post_connector_dataset

        Create Connector Dataset
        """
        pass

    def test_post_project_available_dataset(self) -> None:
        """Test case for post_project_available_dataset

        Create Project Available Dataset
        """
        pass

    def test_post_project_dataset(self) -> None:
        """Test case for post_project_dataset

        Create Project Dataset
        """
        pass

    def test_put_available_dataset_schema(self) -> None:
        """Test case for put_available_dataset_schema

        Update Available Dataset Schema
        """
        pass

    def test_put_connector_available_datasets(self) -> None:
        """Test case for put_connector_available_datasets

        Overwrite Connector Available Datasets
        """
        pass

    def test_put_dataset_schema(self) -> None:
        """Test case for put_dataset_schema

        Update Dataset Schema
        """
        pass


if __name__ == '__main__':
    unittest.main()
