# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.data_retrieval_v1_api import DataRetrievalV1Api


class TestDataRetrievalV1Api(unittest.TestCase):
    """DataRetrievalV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = DataRetrievalV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_available_data_retrieval_data(self) -> None:
        """Test case for delete_available_data_retrieval_data

        Delete Retrieved Data
        """
        pass

    def test_delete_data_retrieval_data(self) -> None:
        """Test case for delete_data_retrieval_data

        Delete Retrieved Data
        """
        pass

    def test_get_available_data_retrieval_data(self) -> None:
        """Test case for get_available_data_retrieval_data

        Gets Raw Data Operation Data
        """
        pass

    def test_get_data_retrieval_data(self) -> None:
        """Test case for get_data_retrieval_data

        Gets Raw Data Operation Data
        """
        pass

    def test_post_available_data_retrieval_operation(self) -> None:
        """Test case for post_available_data_retrieval_operation

        Create Raw Data Operation
        """
        pass

    def test_post_data_retrieval_operation(self) -> None:
        """Test case for post_data_retrieval_operation

        Create Raw Data Operation
        """
        pass

    def test_put_available_data_retrieval_data(self) -> None:
        """Test case for put_available_data_retrieval_data

        Put Retrieved Data
        """
        pass

    def test_put_data_retrieval_data(self) -> None:
        """Test case for put_data_retrieval_data

        Put Retrieved Data
        """
        pass


if __name__ == '__main__':
    unittest.main()
